==> nextcloud-19.0.6.tgz: nextcloud/apps/accessibility/l10n/zh_CN.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "深色主题",
    "Enable dark theme" : "启用深色主题",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "一款通过降低整体亮度来使您的眼睛放松的深色主题。该主题目前还在开发中，如发现问题请您及时向我们反馈。",
    "High contrast mode" : "高对比度模式",
    "Enable high contrast mode" : "启用高对比度模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "使用高对比度模式。图像质量会下降，但清晰度会提升。",
    "Dyslexia font" : "阅读障碍字体",
    "Enable dyslexia font" : "启用阅读障碍字体",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic是一款免费的字样/字体，这款字体的设计目的是缓解由阅读障碍引起的一些常见阅读错误。",
    "Accessibility" : "易用性",
    "Accessibility options for nextcloud" : "Nextcloud的易用性选项",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "提供多种易用性选项以便于您使用Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "通用访问对我们非常重要。 我们遵循网络标准，并进行检查以确保所有内容都可以在没有鼠标或辅助软件（例如屏幕阅读器）的情况下使用。 我们的目标是遵守 {guidelines} Web 内容可访问性指南 {linkend} 2.1 能达到 AA 级别，具有高对比度主题甚至能达到 AAA 级别。",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "如果您发现任何问题，请随时在 {issuetracker} 我们的问题跟踪器 {linkend} 上报告。 如果您想参与其中，请加入 {designteam} 我们的设计团队 {linkend}！",
    "Enable" : "启用"
},
"nplurals=1; plural=0;");

==> nextcloud-21.0.0p0.tgz: nextcloud/apps/accessibility/l10n/zh_CN.js <==
OC.L10N.register(
    "accessibility",
    {
    "Dark theme" : "深色主题",
    "Enable dark theme" : "启用深色主题",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness. It is still under development, so please report any issues you may find." : "一款通过降低整体亮度来使您的眼睛放松的深色主题。该主题目前还在开发中，如发现问题请您及时向我们反馈。",
    "High contrast mode" : "高对比度模式",
    "Enable high contrast mode" : "启用高对比度模式",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "使用高对比度模式。图像质量会下降，但清晰度会提升。",
    "Dyslexia font" : "阅读障碍字体",
    "Enable dyslexia font" : "启用阅读障碍字体",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic是一款免费的字样/字体，这款字体的设计目的是缓解由阅读障碍引起的一些常见阅读错误。",
    "Accessibility" : "辅助功能",
    "Accessibility options for nextcloud" : "Nextcloud的辅助功能",
    "Provides multiple accessibilities options to ease your use of Nextcloud" : "提供多种辅助功能以便于您使用Nextcloud",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "通用访问对我们非常重要。 我们遵循网络标准，并进行检查以确保所有内容都可以在没有鼠标或辅助软件（例如屏幕阅读器）的情况下使用。 我们的目标是遵守 {guidelines} Web 内容可访问性指南 {linkend} 2.1 能达到 AA 级别，具有高对比度主题甚至能达到 AAA 级别。",
    "If you find any issues, don’t hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "如果您发现任何问题，请随时在 {issuetracker} 我们的问题跟踪器 {linkend} 上报告。 如果您想参与其中，请加入 {designteam} 我们的设计团队 {linkend}！"
},
"nplurals=1; plural=0;");
